@@ -20,13 +20,6 @@
 #include <QPushButton>
 #include <QWidget>
 
-#if HAVE_KACTIVITIES
-namespace KActivities
-{
-class ResourceInstance;
-}
-#endif
-
 class FilterBar;
 class KMessageWidget;
 class QAction;
@@ -326,6 +319,11 @@ private Q_SLOTS:
      */
     void slotItemsActivated(const KFileItemList &items);
 
+    /**
+     * Handles middle click of file. It opens the file passed using the second application associated with the file's mimetype.
+     */
+    void slotfileMiddleClickActivated(const KFileItem &item);
+
     /**
      * Shows the information for the item \a item inside the statusbar. If the
      * item is null, the default statusbar information is shown.
@@ -377,6 +375,7 @@ private Q_SLOTS:
      * Gets the search URL from the searchbox and starts searching.
      */
     void startSearching();
+    void openSearchBox();
     void closeSearchBox();
 
     /**
@@ -468,11 +467,6 @@ private:
      * connected to this ViewContainer.
      */
     std::unique_ptr<DolphinUrlNavigator::VisualState> m_urlNavigatorVisualState;
-
-#if HAVE_KACTIVITIES
-private:
-    KActivities::ResourceInstance *m_activityResourceInstance;
-#endif
 };
 
 #endif // DOLPHINVIEWCONTAINER_H
